<template>
  <div class="mod-config">
    <basic-container>
      <el-row>
        <el-col :span="10">
          <ttable
            :table="table"
            @currentChange="handleCurrentChange"
            :uploadInfo="uploadInfo"
            :prelang="prelang"
            :options="options"
            :ajaxFun="ajaxFun"
            ref="handymanTemplateTable"
          >
            <template #toolbar></template>
          </ttable>
        </el-col>
        <el-col :span="14" style="padding-left: 10px">
          <ttable
            :table="joinTable"
            @handleSelectionChange="joinHandleSelectionChange"
            :uploadInfo="joinUploadInfo"
            :prelang="joinPrelang"
            :options="joinOptions"
            :ajaxFun="joinAjaxFun"
            :paramObj="paramObj"
            ref="joinTypeTemplateTable"
          >
            <template #toolbar></template>
          </ttable>
        </el-col>
      </el-row>
      <!-- 弹窗, 模板新增 / 修改 -->
      <template-form v-if="addOrUpdateVisible" ref="addOrUpdate" @refreshDataList="getData"></template-form>
      <!-- 人工模板关联人工类型 -->
      <handymanTypeDialog :currshowlist.sync="relateVisible" :handymanTemplateId="currentHandymanTemplateId"
                          :wageTypeOptions="wageTypeOptions" :loadTypeOptions="loadTypeOptions" :paramObj="paramObj"
                          :unitOptions="unitOptions" @handleSelectionChange="getJoinData"/>
    </basic-container>
  </div>
</template>

<script>
  import {fetchListHandymanTemplate, delHandymanTemplate} from '@/api/product/handymantemplate'
  import {fetchListByTemplateId,delTypeTemplate} from '@/api/product/handymantype'
  import TemplateForm from './handymantemplate-form'
  import {mapGetters} from 'vuex'
  import ttable from '@/views/common/ztt-table.vue'
  import handymanTypeDialog from './handymantype'
  import {remote} from "@/api/admin/dict"

  export default {
    data() {
      return {
        ajaxFun: fetchListHandymanTemplate,
        addOrUpdateVisible: false,
        currentHandymanTemplateId: 0,
        uploadInfo: {//是否展示上传EXCEL以及对应的url
          isShow: false,
          url: ''
        },
        prelang: "operation",
        options: {
          height: 300,//默认高度-为了表头固定
          stripe: true, // 是否为斑马纹 table
          highlightCurrentRow: false, // 是否要高亮当前行
          border: true,//是否有纵向边框
          lazy: false,//是否需要懒加载
          fit: true,//列的宽度是否自撑开
          multiSelect: false,//
          seqNo: true,
          isRefresh: true,//是否显示刷新按钮
          isShowHide: true,//是否显示显影按钮
          isSearch: false,//高级查询按钮
          defaultOrderBy: {column: 'templateNo', direction: 'desc'}
        },
        table: {
          total: 0,
          currentPage: 1,
          pageSize: 20,
          data: [],
          // 标题
          column: [
            {width:'180',prop:"templateNo",label:"模板编号",sort: true,isTrue:true,isSearch:true,searchInfoType:'text',render:{fun:this.addOrUpdateHandle}},
            {width:'180',prop:"templateDescription",label:"模板名称",sort: true,isTrue:true,isSearch:true,searchInfoType:'text' },
            {width:'100',prop:"remark",label:"备注",sort: true,isTrue:true,isSearch:true,searchInfoType:'text' },
          ],
          toolbar: [
            {
              text: '新增模板',
              type: 'primary',
              fun: this.addOrUpdateHandle
            }
          ],
          operator: [
            {
              text: '删除',
              type: 'text',
              size: 'small',
              fun: this.deleteHandle
            }
          ],
          operatorConfig: {
            fixed: 'right',
            label: '操作',
            width: 60,
            minWidth: 60
          },
        },


        paramObj:{"handymanTemplateId":0},
        joinAjaxFun: fetchListByTemplateId,
        relateVisible: false,
        joinMultipleSelection: [],
        joinUploadInfo: {//是否展示上传EXCEL以及对应的url
          isShow: false,
          url: ''
        },
        joinPrelang: "operation",
        joinOptions: {
          height: 300,//默认高度-为了表头固定
          stripe: true, // 是否为斑马纹 table
          highlightCurrentRow: false, // 是否要高亮当前行
          border: true,//是否有纵向边框
          lazy: false,//是否需要懒加载
          fit: true,//列的宽度是否自撑开
          multiSelect: true,//
          seqNo: true,
          isRefresh: true,//是否显示刷新按钮
          isShowHide: true,//是否显示显影按钮
          isSearch: false,//高级查询按钮
          defaultOrderBy: {column: 'handymanNo', direction: 'desc'}
        },
        joinTable: {
          total: 0,
          currentPage: 1,
          pageSize: 20,
          data: [],
          // 标题
          column: [
            {width:'140',prop:"handymanNo",label:"人工编号",sort: true,isTrue:true,isSearch:true,searchInfoType:'text' },
            {width:'140',prop:"handymanName",label:"人工名称",sort: true,isTrue:true,isSearch:true,searchInfoType:'text' },
            {width:'100',prop:"conversionCoefficient",label:"转化系数",sort: true,isTrue:true,isSearch:true,searchInfoType:'number' },
            {width:'100',prop:"standardHourWage",label:"标准工时系数",sort: true,isTrue:true,isSearch:true,searchInfoType:'number' },
            {width:'100',prop:"discountFactor",label:"折扣系数",sort: true,isTrue:true,isSearch:true,searchInfoType:'number' },
            {width:'100',prop:"wageType",label:"工资类型",sort: true,isTrue:true,isSearch:true,searchInfoType:'select',formatter:this.formatWageType,optList:() => {return this.wageTypeOptions} },
            {width:'100',prop:"loadType",label:"工作量类型",sort: true,isTrue:true,isSearch:true,searchInfoType:'select',formatter:this.formatLoadType,optList:() => {return this.loadTypeOptions}  },
            {width:'140',prop:"comment",label:"备注",sort: true,isTrue:true,isSearch:true,searchInfoType:'text' },
            {width:'100',prop:"unit",label:"单位",sort: true,isTrue:true,isSearch:true,searchInfoType:'select',formatter:this.formatUnit,optList:() => {return this.unitOptions}  },
          ],
          toolbar: [
            {
              text: '关联人工',
              type: 'primary',
              fun: this.relateHandle
            }
          ],
          operator: [
            {
              text: '删除',
              type: 'text',
              size: 'small',
              fun: this.joinDeleteHandle
            }
          ],
          operatorConfig: {
            fixed: 'right',
            label: '操作',
            width: 60,
            minWidth: 60
          },
        },
        wageTypeOptions:[],
        loadTypeOptions:[],
        unitOptions:[],
      }
    },
    components: {
      TemplateForm,
      ttable,
      handymanTypeDialog
    },
    computed: {
      ...mapGetters(['permissions'])
    },
    created () {
      this.initOptions()
    },
    methods: {
      // 获取数据列表
      getData() {
        this.$refs.handymanTemplateTable.getDataList()
      },
      // 新增 / 修改
      addOrUpdateHandle(row) {
        this.addOrUpdateVisible = true
        this.$nextTick(() => {
          this.$refs.addOrUpdate.init(row == null ? null : row.id)
        })
      },
      // 删除
      deleteHandle(row) {
        this.$confirm('是否确认删除人工名模板名称为：' + row.templateDescription, '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          closeOnClickModal: false,
          type: 'warning'
        }).then(function () {
          return delHandymanTemplate(row.id)
        }).then(data => {
          this.$message.success('删除成功')
          this.getData()
        })
      },
      handleCurrentChange(row) {
        if (!this.currentHandymanTemplateId || this.currentHandymanTemplateId!=row.id){
          this.currentHandymanTemplateId = row.id
          this.paramObj = {"handymanTemplateId":row.id}
          this.$nextTick(() => {
            this.getJoinData()
          })
        }
      },


      getJoinData() {
        this.$refs.joinTypeTemplateTable.getDataList()
      },
      relateHandle() {
        if (this.currentHandymanTemplateId){
          this.relateVisible = true
        }else{
          this.$message.warning('请先选择一条人工模板')
        }
      },
      joinHandleSelectionChange(val) {
        this.joinMultipleSelection = val
      },
      // 删除
      joinDeleteHandle(row) {
        this.$confirm('是否确认删除人工名称为：' + row.handymanName, '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          closeOnClickModal: false,
          type: 'warning'
        }).then(function () {
          return delTypeTemplate(Object.assign({"handymanTemplateId":row.handymanTemplateId,"handymanTypeId":row.id}))
        }).then(data => {
          this.$message.success('删除成功')
          this.getJoinData()
        })
      },

      //获取数据字典-工资类型
      initOptions(){
        remote('wage_type').then(response => {
          if (response.data.code === 0) {
            this.wageTypeOptions = response.data.data
          }
        })
        remote('load_type').then(response => {
          if (response.data.code === 0) {
            this.loadTypeOptions = response.data.data
          }
        })
        remote('workload_unit').then(response => {
          if (response.data.code === 0) {
            this.unitOptions = response.data.data
          }
        })
      },
      // 表格字段格式化
      formatWageType(row, column, cellValue) {
        for (let i = 0, len = this.wageTypeOptions.length; i < len; i++) {
          if (cellValue == this.wageTypeOptions[i].value) {
            return this.wageTypeOptions[i].label
          }
        }
      },
      formatLoadType(row, column, cellValue) {
        for (let i = 0, len = this.loadTypeOptions.length; i < len; i++) {
          if (cellValue == this.loadTypeOptions[i].value) {
            return this.loadTypeOptions[i].label
          }
        }
      },
      formatUnit(row, column, cellValue) {
        for (let i = 0, len = this.unitOptions.length; i < len; i++) {
          if (cellValue == this.unitOptions[i].value) {
            return this.unitOptions[i].label
          }
        }
      },
    }
  }
</script>
